Crate hepmc2_macros
hepmc2_
macros
0.1.0
All Items
Crate Items
Attribute Macros
Crate
hepmc2_
macros
Attribute Macros

read_
bound
Adds the trait bounds required for either sync or async reading
write_
bound
Adds the trait bounds required for either sync or async writing